/*!
 * rivet-core - @version 2.0.0-alpha.2

 * Copyright (C) 2018 The Trustees of Indiana University
 * SPDX-License-Identifier: BSD-3-Clause
 */

var Rivet = (function (exports) {
  'use strict';

  if (!Element.prototype.closest) {
    if (!Element.prototype.matches) {
      Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector;
    }

    Element.prototype.closest = function (s) {
      var el = this;
      var ancestor = this;
      if (!document.documentElement.contains(el)) return null;

      do {
        if (ancestor.matches(s)) return ancestor;
        ancestor = ancestor.parentElement;
      } while (ancestor !== null);

      return null;
    };
  }

  (function () {
    if (typeof window.CustomEvent === 'function') return false;

    function CustomEvent(event, params) {
      params = params || {
        bubbles: false,
        cancelable: false,
        detail: undefined
      };
      var evt = document.createEvent('CustomEvent');
      evt.initCustomEvent(event, params.bubbles, params.cancelable, params.detail);
      return evt;
    }

    CustomEvent.prototype = window.Event.prototype;
    window.CustomEvent = CustomEvent;
  })();

  (function (arr) {
    arr.forEach(function (item) {
      if (item.hasOwnProperty('remove')) {
        return;
      }


      Object.defineProperty(item, 'remove', {
        configurable: true,
        enumerable: true,
        writable: true,
        value: function remove() {
          if (this.parentNode === null) {
            return;
          }

          this.parentNode.removeChild(this);
        }
      });
    });
  })([Element.prototype, CharacterData.prototype, DocumentType.prototype]);

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    return Constructor;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);

    if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);
      if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
      keys.push.apply(keys, symbols);
    }

    return keys;
  }

  function _objectSpread2(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};

      if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }

    return target;
  }

  var globalSettings = {
    prefix: 'rvt'
  };

  var prefix = globalSettings.prefix;

  function dispatchCustomEvent(eventName, element, detail) {
    var newEvent = new CustomEvent("".concat(prefix, ":").concat(eventName), {
      bubbles: true,
      cancelable: true,
      detail: detail
    });
    var eventShouldFire = element.dispatchEvent(newEvent);
    return eventShouldFire;
  }


  var nodeListToArray = function nodeListToArray(nodes) {
    return Array.prototype.slice.call(nodes);
  };

  var isNode = function isNode(element) {
    return element.nodeType === 1 || element.nodeType === 1;
  };

  var keyCodes = {
    up: 38,
    down: 40,
    left: 37,
    right: 39,
    tab: 9,
    enter: 13,
    escape: 27,
    home: 36,
    end: 35,
    pageUp: 33,
    pageDown: 34
  };

  var Accordion =
  function () {
    function Accordion(element, options) {
      var _this = this;

      _classCallCheck(this, Accordion);

      var defaultOptions = {
        openAllOnInit: false
      };

      var settings = _objectSpread2({}, defaultOptions, {}, options); 


      this.openAllOnInit = settings.openAllOnInit;
      this.element = element; 

      if (!isNode(this.element)) {
        throw new TypeError('A DOM element should be passed as the first argument to initialize the accordion.');
      }

      this.triggerAttribute = 'data-accordion-trigger';
      this.triggerSelector = "[".concat(this.triggerAttribute, "]");
      this.triggers = nodeListToArray(this.element.querySelectorAll(this.triggerSelector));

      if (this.triggers.length < 2) {
        throw new TypeError('An accordion should contain *at least two* accordion triggers with the "data-accordion-trigger" attribute');
      }

      this.panelAttribute = 'data-accordion-panel';
      this.panelSelector = "[".concat(this.panelAttribute, "]");
      this.panels = nodeListToArray(this.element.querySelectorAll(this.panelSelector));
      var initializedPanels = this.element.querySelectorAll("[data-accordion-panel-init]"); 

      try {
        if (initializedPanels.length > 1) {
          throw new TypeError('Caught');
        }

        var initialPanel; 

        this.panels.forEach(function (panel, index) {
          if (panel.hasAttribute('data-accordion-panel-init')) {
            initialPanel = panel;
          } else {
            _this.panels[index].setAttribute('hidden', '');
          }
        }); 

        this.openOnInit = initialPanel;
      } catch (e) {
        console.warn('Only one accordion panel should have the data-accordion-panel-init attribute. If you wish to open all panels on initialization, please apply the appropriate attribute to the data-accordion element');
      } 


      this._handleClick = this._handleClick.bind(this);
      this._handleKeydown = this._handleKeydown.bind(this);
      this.init();
    }


    _createClass(Accordion, [{
      key: "_handleClick",
      value: function _handleClick(event) {
        var currentTrigger = event.target.closest(this.triggerSelector); 

        if (!currentTrigger) return; 

        var currentTriggerValue = currentTrigger.getAttribute(this.triggerAttribute); 

        var currentPanel = this.element.querySelector("[".concat(this.panelAttribute, "=\"").concat(currentTriggerValue, "\"]")); 

        currentTrigger.getAttribute('aria-expanded') === 'true' ? this.close(currentPanel) : this.open(currentPanel);
      }

    }, {
      key: "_handleKeydown",
      value: function _handleKeydown(event) {
        if (event.keyCode === keyCodes.up || event.keyCode === keyCodes.down || event.keyCode === keyCodes.end || event.keyCode === keyCodes.home) {
          var accordionParent = event.target.closest('[data-accordion]'); 

          if (!accordionParent) return;
          var currentTrigger = event.target.closest(this.triggerSelector);
          if (!currentTrigger) return; 

          var nextTrigger = this.triggers.indexOf(currentTrigger) + 1;
          var prevTrigger = this.triggers.indexOf(currentTrigger) - 1;

          switch (event.keyCode) {
            case keyCodes.up:
              {
                if (this.triggers[prevTrigger] === undefined) {
                  this.triggers[this.triggers.length - 1].focus();
                } else {
                  this.triggers[prevTrigger].focus();
                }

                break;
              }

            case keyCodes.down:
              {
                if (this.triggers[nextTrigger] === undefined) {
                  this.triggers[0].focus();
                } else {
                  this.triggers[nextTrigger].focus();
                }

                break;
              }

            case keyCodes.end:
              {
                this.triggers[this.triggers.length - 1].focus();
                break;
              }

            case keyCodes.home:
              {
                this.triggers[0].focus();
                break;
              }
          }
        }
      }

    }, {
      key: "_openOnInit",
      value: function _openOnInit() {
        var _this2 = this;

        if (this.openAllOnInit === true) {
          this.panels.forEach(function (panel) {
            _this2.open(panel);
          });
        } else {
          this.panels.forEach(function (panel, index) {
            if (panel !== _this2.openOnInit) {
              _this2.panels[index].setAttribute('hidden', '');

              var trigger = _this2.element.querySelector("[".concat(_this2.triggerAttribute, "=\"").concat(panel.dataset.accordionPanel, "\"]")); 


              trigger.setAttribute('aria-expanded', 'false');
            } else {
              _this2.open(_this2.openOnInit);
            }
          });
        }
      }

    }, {
      key: "open",
      value: function open(accordion, callback) {
        var activationEvent = dispatchCustomEvent('accordionOpened', accordion, {
          id: accordion.dataset.accordionPanel
        });
        if (!activationEvent) return;
        var trigger = this.element.querySelector("[".concat(this.triggerAttribute, " = \"").concat(accordion.dataset.accordionPanel, "\"]")); 

        accordion.removeAttribute('hidden');
        trigger.setAttribute('aria-expanded', 'true');

        if (callback && typeof callback === 'function') {
          callback();
        }
      }

    }, {
      key: "close",
      value: function close(accordion, callback) {
        var activationEvent = dispatchCustomEvent('accordionClosed', accordion, {
          id: accordion.dataset.accordionPanel
        });
        if (!activationEvent) return;
        var trigger = this.element.querySelector("[".concat(this.triggerAttribute, " = \"").concat(accordion.dataset.accordionPanel, "\"]")); 

        accordion.setAttribute('hidden', '');
        trigger.setAttribute('aria-expanded', 'false');

        if (callback && typeof callback === 'function') {
          callback();
        }
      }
    }, {
      key: "init",
      value: function init() {
        this._openOnInit(); 


        this.element.addEventListener('click', this._handleClick, false);
        this.element.addEventListener('keydown', this._handleKeydown, false);
      }
    }, {
      key: "destroy",
      value: function destroy() {
        this.element.removeEventListener('click', this._handleClick, false);
        this.element.removeEventListener('keydown', this._handleKeydown, false);
      }
    }]);

    return Accordion;
  }();

  var Alert =
  function () {
    function Alert(element) {
      _classCallCheck(this, Alert);

      this.element = element;
      this.closeAttribute = 'data-alert-close';
      this.closeSelector = "[".concat(this.closeAttribute, "]");
      this.closeButton = null; 

      this._handleClick = this._handleClick.bind(this); 

      if (!isNode(this.element)) {
        throw new TypeError('A DOM element should be passed as the first argument to initialize the alert');
      }

      this.init();
    }

    _createClass(Alert, [{
      key: "_handleClick",
      value: function _handleClick() {
        this.dismiss();
      }
    }, {
      key: "dismiss",
      value: function dismiss() {
        var dismissEvent = dispatchCustomEvent('alertDismiss', this.element, {
          id: this.element.dataset.alert
        });
        if (!dismissEvent) return;
        this.destroy();
        this.element.remove();
      }
    }, {
      key: "init",
      value: function init() {
        this.closeButton = this.element.querySelector(this.closeSelector);
        this.closeButton.addEventListener('click', this._handleClick, false);
      }
    }, {
      key: "destroy",
      value: function destroy() {
        this.closeButton.addEventListener('click', this._handleClick, false);
      }
    }]);

    return Alert;
  }();

  var Dropdown =
  function () {
    function Dropdown(element) {
      _classCallCheck(this, Dropdown);

      this.element = element;
      this.focusableElements = 'a[href], area[href], input:not([disabled]), select:not([disabled]), textarea:not([disabled]), button:not([disabled]), [tabindex="0"]';
      this.dropdownAttribute = '[data-dropdown]';
      this.toggleAttribute = '[data-dropdown-toggle]';
      this.toggleElement = this.element.querySelector(this.toggleAttribute);
      this.menuAttribute = '[data-dropdown-menu]';
      this.menuElement = this.element.querySelector(this.menuAttribute); 

      this.isOpen = false;
      this.activeToggle = null;
      this.activeMenu = null; 

      this._handleClick = this._handleClick.bind(this);
      this._handleKeydown = this._handleKeydown.bind(this); 

      this.element.querySelector('svg').setAttribute('focusable', 'false');
      this.init();
    }

    _createClass(Dropdown, [{
      key: "open",
      value: function open() {
        if (this.toggleElement.hasAttribute('disabled')) {
          return;
        }

        var openEvent = dispatchCustomEvent('dropdownOpen', this.toggleElement, {
          id: this.toggleElement.dataset.dropdownToggle
        });
        if (!openEvent) return;
        this.isOpen = true;
        this.toggleElement.setAttribute('aria-expanded', 'true'); 

        this.menuElement.removeAttribute('hidden'); 

        this.activeToggle = this.toggleElement;
        this.activeMenu = this.menuElement;
      }
    }, {
      key: "close",
      value: function close() {
        if (!this.activeToggle) return;
        var closeEvent = dispatchCustomEvent('dropdownClose', this.toggleElement, {
          id: this.toggleElement.dataset.dropdownToggle
        });
        if (!closeEvent) return;
        this.isOpen = false;
        this.activeToggle.setAttribute('aria-expanded', 'false');
        this.activeMenu.setAttribute('hidden', ''); 

        this.activeToggle = null;
        this.activeMenu = null;
      }

    }, {
      key: "_setUpMenu",
      value: function _setUpMenu(menu) {
        var menuObject = {}; 

        var menuFocusables = nodeListToArray(menu.querySelectorAll(this.focusableElements)); 

        menuObject.all = menuFocusables; 

        menuObject.first = menuFocusables[0]; 

        menuObject.last = menuFocusables[menuFocusables.length - 1];
        return menuObject;
      }
    }, {
      key: "_handleClick",
      value: function _handleClick(event) {
        var toggle = event.target.closest(this.toggleAttribute); 

        if (this.menuElement.contains(event.target)) return; 

        if (!toggle && this.activeToggle !== null) {
          this.close();
          return;
        } 


        if (toggle !== this.toggleElement || this.isOpen) {
          this.close();
        } else {
          this.open();
        }
      }
    }, {
      key: "_handleKeydown",
      value: function _handleKeydown(event) {
        if (!this.element.contains(event.target)) return; 

        var dropdown = event.target.closest(this.dropdownAttribute);
        if (dropdown !== this.element) return;

        switch (event.keyCode) {
          case keyCodes.down:
            {
              event.preventDefault();

              if (!this.isOpen) {
                this.open();
              } else {
                var _currentMenu = this._setUpMenu(this.menuElement);

                _currentMenu.first.focus();
              }


              if (!this.menuElement.contains(event.target)) break;

              var currentMenu = this._setUpMenu(this.menuElement);

              var currentIndex;

              for (var i = 0; i < currentMenu.all.length; i++) {
                if (event.target == currentMenu.all[i]) {
                  currentIndex = i;
                }
              }

              var nextItem = currentMenu.all[currentIndex + 1];

              if (!nextItem) {
                currentMenu.first.focus();
                return;
              }

              nextItem.focus();
              break;
            }

          case keyCodes.up:
            {
              event.preventDefault();

              if (!this.menuElement.contains(event.target)) break;

              var _currentMenu2 = this._setUpMenu(this.menuElement);

              var _currentIndex;

              for (var _i = 0; _i < _currentMenu2.all.length; _i++) {
                if (event.target == _currentMenu2.all[_i]) {
                  _currentIndex = _i;
                }
              }

              var previousItem = _currentMenu2.all[_currentIndex - 1];

              if (!previousItem && _currentMenu2.last !== undefined) {
                _currentMenu2.last.focus();

                return;
              }

              previousItem.focus();
              break;
            }

          case keyCodes.escape:
            {
              if (!this.activeToggle) return; 

              this.close();
              this.toggleElement.focus();

              this.activeToggle = null;
              break;
            }

          case keyCodes.tab:
            {
              if (!this.menuElement.contains(event.target)) break;

              var _currentMenu3 = this._setUpMenu(this.menuElement); 


              if (document.activeElement == _currentMenu3.last && !event.shiftKey) {
                this.close();
                return;
              }

              break;
            }
        }
      }
    }, {
      key: "init",
      value: function init() {
        document.addEventListener('click', this._handleClick, false);
        document.addEventListener('keydown', this._handleKeydown, false);
      }
    }, {
      key: "destroy",
      value: function destroy() {
        document.removeEventListener('click', this._handleClick, false);
        document.removeEventListener('keydown', this._handleKeydown, false);
      }
    }]);

    return Dropdown;
  }();

  var FileInput =
  function () {
    function FileInput(element, options) {
      _classCallCheck(this, FileInput);

      var defaultOptions = {
        previewText: 'No file selected'
      };

      var settings = _objectSpread2({}, defaultOptions, {}, options);

      this.element = element;
      this.wrapperAttribute = 'data-upload-wrapper';
      this.inputAttribute = 'data-upload-input';
      this.previewAttribute = 'data-upload-preview';
      this.previewText = settings.previewText;
      this._handleChange = this._handleChange.bind(this);
      this.init();
    }


    _createClass(FileInput, [{
      key: "_sanitizeHTML",
      value: function _sanitizeHTML(str) {
        var temp = document.createElement('div');
        temp.textContent = str;
        return temp.innerHTML;
      }

    }, {
      key: "_buildSingleFile",
      value: function _buildSingleFile(input) {
        var singleFileItem = document.createElement('span');

        var singleFileName = this._sanitizeHTML(input.files[0].name); 


        singleFileItem.textContent = singleFileName; 

        return singleFileItem;
      }

    }, {
      key: "_buildMultipleFiles",
      value: function _buildMultipleFiles(input) {
        var fileCount = document.createElement('span');
        fileCount.textContent = input.files.length + ' files selected';
        return fileCount;
      }
    }, {
      key: "_handleChange",
      value: function _handleChange() {
        var uploadInput = this.element.querySelector("[".concat(this.inputAttribute, "]")); 

        var uploadPreview = this.element.querySelector("[".concat(this.previewAttribute, "]")); 

        if (uploadInput.files.length > 0) {
          uploadPreview.innerHTML = '';

          uploadInput.files.length > 1 ? uploadPreview.appendChild(this._buildMultipleFiles(uploadInput)) : uploadPreview.appendChild(this._buildSingleFile(uploadInput));
        } else {
          uploadPreview.innerHTML = this.previewText;
        }
      }
    }, {
      key: "init",
      value: function init() {
        this.element.addEventListener('change', this._handleChange, false);
      }
    }, {
      key: "destroy",
      value: function destroy() {
        this.element.removeEventListener('change', this._handleChange, false);
      }
    }]);

    return FileInput;
  }();

  var Modal =
  function () {
    function Modal(element, options) {
      _classCallCheck(this, Modal);

      var defaultOptions = {
        openOnInit: false,
        dialog: false
      };

      var settings = _objectSpread2({}, defaultOptions, {}, options); 


      this.element = element; 

      if (!isNode(this.element)) {
        throw new TypeError('A DOM element should be passed as the first argument to initialize the modal.');
      }

      this.openOnInit = settings.openOnInit;
      this.dialog = settings.dialog;
      this.modalAttribute = 'data-modal';
      this.modalSelector = "[".concat(this.modalAttribute, "]");
      this.modalDataValue = this.element.getAttribute('data-modal');
      this.innerModalAttribute = 'data-modal-inner';
      this.innerModalSelector = "[".concat(this.innerModalAttribute, "]");
      this.openAttribute = 'data-modal-trigger';
      this.openSelector = "[".concat(this.openAttribute, "]");
      this.openButton = document.querySelector("[".concat(this.openAttribute, "=\"").concat(this.modalDataValue, "\"]"));
      this.closeAttribute = 'data-modal-close';
      this.closeSelector = "[".concat(this.closeAttribute, "]"); 

      this.focusElements = 'a[href], area[href], input:not([disabled]), select:not([disabled]), textarea:not([disabled]), button:not([disabled]), [tabindex="-1"]'; 

      this._handleClick = this._handleClick.bind(this);
      this._handleKeydown = this._handleKeydown.bind(this);
      this.init();
    }


    _createClass(Modal, [{
      key: "_handleClick",
      value: function _handleClick(event) {
        event.target.closest(this.innerModalSelector) !== null ? event.clickedInModal = true : event.clickedInModal = false;

        if (event.clickedInModal) {
          event.stopPropagation();
        } 


        var triggerSelectors = "".concat(this.openSelector, ", ").concat(this.closeSelector, ", ").concat(this.modalSelector);
        var trigger = event.target.closest(triggerSelectors); 

        if (!trigger) return; 

        var triggerContent;

        if (trigger.getAttribute(this.openAttribute)) {
          triggerContent = trigger.getAttribute(this.openAttribute);
        } else if (trigger.getAttribute(this.closeAttribute)) {
          triggerContent = trigger.getAttribute(this.closeAttribute);
        } else {
          triggerContent = event.target.closest(this.modalSelector);
        } 


        if (!triggerContent) return;

        switch (trigger != null) {
          case trigger.hasAttribute(this.openAttribute):
            {
              if (trigger.getAttribute(this.openAttribute) !== this.modalDataValue) {
                this.close(); 

                return;
              }

              this.open();
              this.element.focus();
              break;
            }

          case trigger.hasAttribute(this.closeAttribute):
            {
              event.preventDefault(); 

              if (trigger.getAttribute(this.closeAttribute) !== this.modalDataValue) return;
              this.close();
              if (this.openButton !== null) this.openButton.focus();
              break;
            }

          case !event.clickedInModal:
            {
              if (this.dialog) return; 

              if (triggerContent.getAttribute(this.modalAttribute) !== this.modalDataValue) return;
              this.close();
              if (this.openButton !== null) this.openButton.focus();
              break;
            }

          default:
            {
              return;
            }
        }
      }

    }, {
      key: "_handleBackwardTab",
      value: function _handleBackwardTab(first, last, event) {
        if (document.activeElement === first || document.activeElement === this.element) {
          event.preventDefault();
          last.focus();
        }
      }

    }, {
      key: "_handleForwardTab",
      value: function _handleForwardTab(first, last, event) {
        if (document.activeElement === last) {
          event.preventDefault();
          first.focus();
        }
      }

    }, {
      key: "_handleKeydown",
      value: function _handleKeydown(event) {
        var currentModal = event.target.closest(this.modalSelector); 

        if (!currentModal) return;

        switch (event.keyCode) {
          case keyCodes.tab:
            {
              var focusList = nodeListToArray(currentModal.querySelectorAll(this.focusElements));
              var firstFocus = focusList[0];
              var finalFocus = focusList[focusList.length - 1]; 

              event.shiftKey ? this._handleBackwardTab(firstFocus, finalFocus, event) : this._handleForwardTab(firstFocus, finalFocus, event);
              break;
            }

          case keyCodes.escape:
            {
              if (this.dialog) return; 

              if (currentModal.getAttribute(this.modalAttribute) !== this.modalDataValue) return;
              this.close();
              if (this.openButton !== null) this.openButton.focus();
              break;
            }
        }
      }

    }, {
      key: "open",
      value: function open(callback) {
        var openEvent = dispatchCustomEvent('modalOpen', this.element, {
          id: this.element.dataset.modal
        });
        if (!openEvent) return;
        this.element.removeAttribute('hidden');
        document.body.classList.add('rvt-modal-open');

        if (callback && typeof callback === 'function') {
          callback();
        }
      }

    }, {
      key: "close",
      value: function close(callback) {
        var closeEvent = dispatchCustomEvent('modalClose', this.element, {
          id: this.element.dataset.modal
        });
        if (!closeEvent) return;
        this.element.setAttribute('hidden', '');
        document.body.classList.remove('rvt-modal-open');

        if (callback && typeof callback === 'function') {
          callback();
        }
      }
    }, {
      key: "focusTrigger",
      value: function focusTrigger() {
        if (!this.openButton) {
          throw new Error("Could not find a modal trigger with the value of ".concat(this.modalDataValue));
        }

        this.openButton.focus();
      }
    }, {
      key: "focusModal",
      value: function focusModal() {
        if (!this.element) {
          throw new Error("Could not find a modal with the value of ".concat(this.modalDataValue));
        }

        this.element.focus();
      }
    }, {
      key: "init",
      value: function init() {
        if (!this.openOnInit) {
          this.element.setAttribute('hidden', '');
        }

        this.destroy(); 

        document.addEventListener('click', this._handleClick, false);
        document.addEventListener('keydown', this._handleKeydown, false);
      }
    }, {
      key: "destroy",
      value: function destroy() {
        document.removeEventListener('click', this._handleClick, false);
        document.removeEventListener('keydown', this._handleKeydown, false);
      }
    }]);

    return Modal;
  }();

  var Sidenav =
  function () {
    function Sidenav(element, options) {
      _classCallCheck(this, Sidenav);

      var defaultOptions = {
        openAllOnInit: false
      };

      var settings = _objectSpread2({}, defaultOptions, {}, options); 


      this.element = element;
      this.openAllOnInit = settings.openAllOnInit;
      this.toggleAttribute = 'data-sidenav-toggle';
      this.toggleSelector = "[".concat(this.toggleAttribute, "]");
      this.listAttribute = 'data-sidenav-list';
      this.listSelector = "[".concat(this.listAttribute, "]"); 

      this._handleClick = this._handleClick.bind(this); 

      if (!isNode(this.element)) {
        throw new TypeError('A DOM element should be passed as the first argument to initialize the sidenav');
      }

      this.init();
    }

    _createClass(Sidenav, [{
      key: "_handleClick",
      value: function _handleClick(event) {
        var toggleButton = event.target.closest(this.toggleSelector); 

        if (!toggleButton) return;
        var toggleId = toggleButton.dataset.sidenavToggle;
        var targetList = this.element.querySelector("[".concat(this.listAttribute, "=\"").concat(toggleId, "\"]")); 

        if (!targetList || targetList.getAttribute(this.listAttribute) === '') {
          return;
        }

        targetList.hasAttribute('hidden') ? this.open(toggleButton, targetList) : this.close(toggleButton, targetList);
      }
    }, {
      key: "open",
      value: function open(toggleButton, targetList) {
        var openEvent = dispatchCustomEvent('sidenavListOpen', toggleButton, {
          id: toggleButton.dataset.sidenavToggle
        });
        if (!openEvent) return;
        toggleButton.setAttribute('aria-expanded', 'true');
        targetList.removeAttribute('hidden');
      }
    }, {
      key: "close",
      value: function close(toggleButton, targetList) {
        var closeEvent = dispatchCustomEvent('sidenavListClose', toggleButton, {
          id: toggleButton.dataset.sidenavToggle
        });
        if (!closeEvent) return;
        toggleButton.setAttribute('aria-expanded', 'false');
        targetList.setAttribute('hidden', '');
      }
    }, {
      key: "init",
      value: function init() {
        var _this = this;

        this.element.addEventListener('click', this._handleClick, false); 

        var menuToggles = nodeListToArray(this.element.querySelectorAll(this.toggleSelector));
        var childMenus = nodeListToArray(this.element.querySelectorAll(this.listSelector));
        menuToggles.forEach(function (element, index) {
          element.setAttribute('aria-haspopup', 'true'); 

          if (_this.openAllOnInit) {
            element.setAttribute('aria-expanded', 'true');
            childMenus[index].removeAttribute('hidden');
            return;
          } 


          if (element.getAttribute('aria-expanded') === 'true') {
            childMenus[index].removeAttribute('hidden');
          } else {
            element.setAttribute('aria-expanded', 'false');
            childMenus[index].setAttribute('hidden', '');
          }
        });
      }
    }, {
      key: "destroy",
      value: function destroy() {
        this.element.removeEventListener('click', this._handleClick, false);
      }
    }]);

    return Sidenav;
  }();

  var Tabs =
  function () {
    function Tabs(element) {
      var _this = this;

      _classCallCheck(this, Tabs);

      this.element = element; 

      if (!isNode(this.element)) {
        throw new TypeError('A DOM element should be passed as the first argument to initialize the modal.');
      }

      this.tablist = this.element.querySelector('[role="tablist"]');
      this.tabAttribute = 'data-tab';
      this.tabSelector = "[".concat(this.tabAttribute, "]");
      this.tabs = nodeListToArray(this.element.querySelectorAll(this.tabSelector));
      this.panelAttribute = 'data-tab-panel';
      this.panelSelector = "[".concat(this.panelAttribute, "]");
      this.panels = nodeListToArray(this.element.querySelectorAll(this.panelSelector)); 

      var initialPanel;
      this.panels.forEach(function (panel, index) {
        if (panel.hasAttribute('data-tab-init')) {
          initialPanel = panel;
        } else {
          _this.tabs[index].setAttribute('tabindex', '-1');
        }
      }); 

      this.openOnInit = initialPanel || this.panels[0]; 

      this._handleClick = this._handleClick.bind(this);
      this._handleKeydown = this._handleKeydown.bind(this);
      this.init();
    }


    _createClass(Tabs, [{
      key: "_handleClick",
      value: function _handleClick(event) {
        var currentTab = event.target.closest(this.tabSelector); 

        if (!currentTab) return; 

        var currentTabValue = currentTab.getAttribute(this.tabAttribute); 

        var currentPanel = this.element.querySelector("[".concat(this.panelAttribute, "=\"").concat(currentTabValue, "\"]")); 

        this.activateTab(currentPanel);
      }

    }, {
      key: "_handleKeydown",
      value: function _handleKeydown(event) {
        var currentTab = event.target.closest(this.tabSelector); 

        if (!currentTab) return; 

        var nextTab = this.tabs.indexOf(currentTab) + 1;
        var prevTab = this.tabs.indexOf(currentTab) - 1;

        switch (event.keyCode) {
          case keyCodes.right :
            {
              !this.tabs[nextTab] ? this.tabs[0].focus() : this.tabs[nextTab].focus();
              break;
            }

          case keyCodes.down:
            {
              !this.tabs[nextTab] ? this.tabs[0].focus() : this.tabs[nextTab].focus();
              break;
            }

          case keyCodes.left:
            {
              !this.tabs[prevTab] ? this.tabs[this.tabs.length - 1].focus() : this.tabs[prevTab].focus();
              break;
            }

          case keyCodes.up:
            {
              !this.tabs[prevTab] ? this.tabs[this.tabs.length - 1].focus() : this.tabs[prevTab].focus();
              break;
            }

          case keyCodes.end:
            {
              this.tabs[this.tabs.length - 1].focus();
              break;
            }

          case keyCodes.home:
            {
              this.tabs[0].focus();
              break;
            }
        }
      }

    }, {
      key: "activateTab",
      value: function activateTab(tab, callback) {
        var _this2 = this;

        var activationEvent = dispatchCustomEvent('tabActivated', tab, {
          id: tab.dataset.tabPanel
        });
        if (!activationEvent) return;
        var trigger = this.element.querySelector("[".concat(this.tabAttribute, "=\"").concat(tab.dataset.tabPanel, "\"]"));
        this.panels.forEach(function (panel, index) {
          if (panel.getAttribute(_this2.panelAttribute) !== tab.dataset.tabPanel) {
            panel.setAttribute('hidden', '');

            _this2.tabs[index].setAttribute('aria-selected', 'false');

            _this2.tabs[index].setAttribute('tabindex', '-1');
          }
        }); 

        tab.removeAttribute('hidden');
        trigger.setAttribute('aria-selected', 'true');
        trigger.removeAttribute('tabindex');

        if (callback && typeof callback === 'function') {
          callback();
        }
      }
    }, {
      key: "init",
      value: function init() {
        this.activateTab(this.openOnInit);
        this.destroy(); 

        this.tablist.addEventListener('click', this._handleClick, false);
        this.tablist.addEventListener('keydown', this._handleKeydown, false);
      }
    }, {
      key: "destroy",
      value: function destroy() {
        this.tablist.removeEventListener('click', this._handleClick, false);
        this.tablist.removeEventListener('keydown', this._handleKeydown, false);
      }
    }]);

    return Tabs;
  }();

  exports.Accordion = Accordion;
  exports.Alert = Alert;
  exports.Dropdown = Dropdown;
  exports.FileInput = FileInput;
  exports.Modal = Modal;
  exports.Sidenav = Sidenav;
  exports.Tabs = Tabs;

  return exports;

}({}));
